Module utils

Module utils 

Traits

RecordBatchUtils

Functions

from_epoch_millis
make_timestamp_parse_formats
str_to_timestamp
Build an expression that converts string to timestamps, following the browser’s unfortunate convention where ISO8601 dates (not timestamps) are always interpreted as UTC, but all other formats are interpreted as the local timezone.
to_epoch_millis